import { useState } from "react";
import useFastAnswerStore from "./useFastAnswerStore";
import { saveReply, updateReply } from "../../services/fast_answer/FastAnswerService";
import toast from 'react-hot-toast';
import useConfigChatStore from "../../store/chat_store/useConfigChatStore";
import { Button, Input, Textarea } from "@nextui-org/react";
import { useTranslation } from "@/src/hooks/useTranslation";

const FastAnswerForm = () => {
    const formFastAnswer = useFastAnswerStore((state) => state.formFastAnswer);
    const optionsView = useFastAnswerStore((state) => state.optionsView);
    const [formAnswer, setFormAnswer] = useState<any>(formFastAnswer);
    const [loading, setLoading] = useState(false);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const getReplies = useFastAnswerStore((state) => state.getReplies);
    const { trans } = useTranslation();

    // Función para manejar cambios en los campos del formulario
    const handleInputChange = (event:any) => {
        const { name, value } = event.target;
        // Actualizamos el estado del formulario con los nuevos valores
        setFormAnswer({
            ...formAnswer,
            [name]: value,
        });
    };

    const handlerSendForm = (e:any) => {
        e.preventDefault();
        setLoading(true);
        const validate = validateForm();
        if (!validate) {
            setLoading(false);
            return
        }
        if (optionsView == 'create_answer') {
            saveReply(id_chatbot,formAnswer.title, formAnswer.description).then((res) => {
                if (res.status == 500) {
                    toast.error(`${trans('modal_conversations_answer_fast_alert_create_error_title')} ${formAnswer.title}`);
                    setLoading(false);
                }else{
                    toast.success(`${trans('modal_conversations_answer_fast_alert_create_success_title')} ${formAnswer.title}`);
                    useFastAnswerStore.setState({ formFastAnswer: formAnswer, optionsView: 'config' })
                }
                getReplies(id_chatbot);
            })
        } else {
            // Actualizamos el estado del formulario con los nuevos valores
            updateReply(id_chatbot,formAnswer.id, formAnswer.title, formAnswer.description).then((res) => {
                if (res.status == 500) {
                    toast.error(`${trans('modal_conversations_answer_fast_alert_edit_error_title')} ${formAnswer.title}`);
                    setLoading(false);
                }else{
                    toast.success(`${trans('modal_conversations_answer_fast_alert_edit_success_title')} ${formAnswer.title}`);
                    useFastAnswerStore.setState({ formFastAnswer: formAnswer, optionsView: 'config' })
                }
                getReplies(id_chatbot);
            })
        }
    }

    const validateForm = () => {
        if (formAnswer.title.trim() == '' || formAnswer.description.trim() == '') {
            toast.error(trans('modal_conversations_answer_fast_alert_error_field_title'));
            return false
        }
        return true
    }

    return (
        <form onSubmit={(e) => handlerSendForm(e)}>
            <h3 className="p-2 pt-0 flex justify-center items-center text-lg">{optionsView == 'create_answer' ? trans('modal_conversations_answer_fast_form_create_title') : trans('modal_conversations_answer_fast_form_edit_title')}</h3>
            <div className="flex flex-col items-center justify-center gap-2">
                <Input
                    label={trans('modal_conversations_answer_fast_form_field_title')}
                    type="text"
                    placeholder={trans('modal_conversations_answer_fast_form_field_title')}
                    value={formAnswer.title}
                    name="title"
                    onChange={(event) => handleInputChange(event)}
                />
                <Textarea
                    label={trans('modal_conversations_answer_fast_form_field_description')}
                    name="description" 
                    value={formAnswer.description}
                    placeholder={trans('modal_conversations_answer_fast_form_field_description')}
                    onChange={(event) => handleInputChange(event)}
                />
            </div>
            <div className="pt-4 p-2 flex justify-center items-center">
                <Button color="primary" size="md" variant="ghost" isLoading={loading} type="submit" onClick={(e) => handlerSendForm(e)}>
                    {optionsView == 'create_answer' ? trans('modal_conversations_answer_fast_form_create_title') : trans('modal_conversations_answer_fast_form_edit_title')}
                </Button>
            </div>
        </form>
    )

}

export default FastAnswerForm